@@ -256,6 +256,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
     "AWS::EC2::TransitGatewayConnectPeer",
+    "AWS::EC2::TransitGatewayMeteringPolicy",
+    "AWS::EC2::TransitGatewayMeteringPolicyEntry",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -283,6 +285,7 @@ types: list[str] = [
     "AWS::EC2::VPNGatewayRoutePropagation",
     "AWS::EC2::Volume",
     "AWS::EC2::VolumeAttachment",
+    "AWS::ECR::PullTimeUpdateExclusion",
     "AWS::ECR::RegistryPolicy",
     "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
@@ -741,11 +744,15 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
+    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
+    "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
+    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -797,7 +804,6 @@ cached: list[str] = [
     "aws-athena-datacatalog.json",
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
-    "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
@@ -837,11 +843,9 @@ cached: list[str] = [
     "aws-cloudformation-waitcondition.json",
     "aws-cloudformation-waitconditionhandle.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
-    "aws-cloudfront-distribution.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-responseheaderspolicy.json",
-    "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
     "aws-cloudwatch-anomalydetector.json",
     "aws-cloudwatch-compositealarm.json",
@@ -927,7 +931,6 @@ cached: list[str] = [
     "aws-ec2-ippoolroutetableassociation.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
-    "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinterface.json",
@@ -954,6 +957,8 @@ cached: list[str] = [
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
     "aws-ec2-transitgatewayconnectpeer.json",
+    "aws-ec2-transitgatewaymeteringpolicy.json",
+    "aws-ec2-transitgatewaymeteringpolicyentry.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -979,11 +984,13 @@ cached: list[str] = [
     "aws-ec2-vpcpeeringconnection.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
+    "aws-ecr-pulltimeupdateexclusion.json",
     "aws-ecr-registrypolicy.json",
     "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
+    "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
@@ -1018,6 +1025,7 @@ cached: list[str] = [
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
+    "aws-elasticloadbalancingv2-targetgroup.json",
     "aws-elasticloadbalancingv2-truststore.json",
     "aws-elasticloadbalancingv2-truststorerevocation.json",
     "aws-elasticsearch-domain.json",
@@ -1101,7 +1109,6 @@ cached: list[str] = [
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
-    "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
@@ -1157,8 +1164,6 @@ cached: list[str] = [
     "aws-lakeformation-tag.json",
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
-    "aws-lambda-eventinvokeconfig.json",
-    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -1183,7 +1188,6 @@ cached: list[str] = [
     "aws-memorydb-subnetgroup.json",
     "aws-memorydb-user.json",
     "aws-msk-batchscramsecret.json",
-    "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
     "aws-msk-replicator.json",
@@ -1214,7 +1218,6 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-pipes-pipe.json",
     "aws-ram-permission.json",
@@ -1303,8 +1306,6 @@ cached: list[str] = [
     "aws-scheduler-schedulegroup.json",
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
-    "aws-secretsmanager-rotationschedule.json",
-    "aws-secretsmanager-secret.json",
     "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-configurationpolicy.json",
@@ -1384,8 +1385,10 @@ cached: list[str] = [
     "aws-wafregional-webaclassociation.json",
     "aws-wafregional-xssmatchset.json",
     "aws-wafv2-ipset.json",
+    "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-regexpatternset.json",
     "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-xray-group.json",
